#ifndef PERIPHERALWIDGET_H
#define PERIPHERALWIDGET_H

#include <QWidget>
#include <QGroupBox>
#include <QVBoxLayout>
#include <QList>
#include <QTimer>
#include "registerwidget.h"
#if defined(SOCEXPLORER_SDK_BUILD)
#  define SOCEXPLORER_SDK_EXPORT Q_DECL_EXPORT
#else
#  define SOCEXPLORER_SDK_EXPORT Q_DECL_IMPORT
#endif

/*
 * TODO ADD an outdated marker
 * Show outdated registers with a different color for example
*/
class SOCEXPLORER_SDK_EXPORT peripheralWidget : public QWidget
{
    Q_OBJECT
public:
    explicit peripheralWidget(const QString& name,qint32 baseAddress, QWidget *parent = 0);
    registerWidget* registerAt(int index)
    {
        if(index>=0 && index<registersWdgts.count())
            return registersWdgts.at(index);
        return NULL;
    }
signals:
    void writeRegSig(qint32 address,qint32 value);
    qint32 readRegSig(qint32 address);
    void clicked(peripheralWidget* sender);
    void upSig(peripheralWidget* sender,int cursorIndex);
    void downSig(peripheralWidget* sender,int cursorIndex);
public slots:
    void blinkCursor();
    void addRegister(const QString& name,qint32 address);
    void leave();
    void enter(int cursorIndex,bool fromTop=true);
protected:
    void mousePressEvent(QMouseEvent *event);
    void mouseMoveEvent(QMouseEvent *event);
    void mouseReleaseEvent(QMouseEvent *event);
    void keyPressEvent(QKeyEvent * event);
    void paintEvent(QPaintEvent* event);

private:
    void up();
    void down();
    QString p_name;
    QString p_header;
    qint32 p_baseAddress;
    QList<registerWidget*> registersWdgts;
    int selectedReg;
    QTimer* p_timer;

};

#endif // PERIPHERALWIDGET_H
